@@ -47,6 +47,7 @@ class Data(object):
     SDATA_UUID = "!sdata_uuid"
     SDATA_CTIME = "!sdata_ctime"
     SDATA_MTIME = "!sdata_mtime"
+    SDATA_PARENT = "!sdata_parent"
 
     def __init__(self, **kwargs):
         """create Data object
@@ -79,6 +80,7 @@ class Data(object):
         self.metadata.add(self.SDATA_UUID, "", dtype="str")
         self.metadata.add(self.SDATA_CTIME, now_utc_str(), dtype="str")
         self.metadata.add(self.SDATA_MTIME, now_utc_str(), dtype="str")
+        self.metadata.add(self.SDATA_PARENT, "", dtype="str")
 
         # auto correct
         if kwargs.get("auto_correct") is None or kwargs.get("auto_correct") is True:
@@ -112,9 +114,27 @@ class Data(object):
         """
         self.metadata.add(self.SDATA_MTIME, now_utc_str())
 
+    @property
+    def sha3_256_table(self):
+        """Return a SHA3 hash of the sData.table object with a hashbit length of 32 bytes.
+
+        .. code-block:: python
+
+            sdata.Data(name="1", uuid=sdata.uuid_from_str("1")).sha3_256_table
+
+            'c468e659891eb5dea6eb6baf73f51ca0688792bf9ad723209dc22730903f6efa'
+
+        :return: hashlib.sha3_256.hexdigest()
+        """
+        s = hashlib.sha3_256()
+        if self.table is not None:
+            tablestr = self.table.to_json().encode(errors="replace")
+            s.update(tablestr)
+        return s.hexdigest()
+
     @property
     def sha3_256(self):
-        """Return a new SHA3 hash object with a hashbit length of 32 bytes.
+        """Return a SHA3 hash of the sData object with a hashbit length of 32 bytes.
 
         .. code-block:: python
 
@@ -846,20 +866,20 @@ class Data(object):
             datac = data.copy()
             print("data  {0.uuid}".format(data))
             print("datac {0.uuid}".format(datac))
-            print("datac.metadata['sdata_uuid_ref'] {0.value}".format(datac.metadata["sdata_uuid_ref"]))
+            print("datac.metadata['!sdata_parent'] {0.value}".format(datac.metadata["sdata_parent"]))
 
         .. code-block::
 
             data  38b26864e7794f5182d38459bab85842
             datac 2c4eb15900af435d8cd9c8573ca777e2
-            datac.metadata['sdata_uuid_ref'] 38b26864e7794f5182d38459bab85842
+            datac.metadata['!sdata_parent'] 38b26864e7794f5182d38459bab85842
 
         :return: Data
         """
         data = copy.deepcopy(self)
-        data.metadata.add("uuid", self.gen_uuid())
-        data.metadata.add("sdata_uuid_ref", self.uuid)
-
+        data.metadata.add(self.SDATA_PARENT, self.uuid)
+        data.metadata.add(self.SDATA_UUID, self.gen_uuid())
+        data.metadata.add(self.SDATA_MTIME, now_utc_str(), dtype="str")
         return data
 
     def gen_uuid(self):
